@@ -15,9 +15,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -39,7 +38,7 @@
 #include "gtksourcecompletionwordsbuffer.h"
 #include "gtksourcecompletionwordsutils.h"
 #include "gtksourceview/gtksource.h"
-#include "gtksourceview/gtksourceview-typebuiltins.h"
+#include "gtksourceview/gtksourceview-enumtypes.h"
 #include "gtksourceview/gtksourceview-i18n.h"
 
 #include <string.h>
@@ -49,7 +48,6 @@
 enum
 {
 	PROP_0,
-
 	PROP_NAME,
 	PROP_ICON,
 	PROP_PROPOSALS_BATCH_SIZE,
@@ -57,7 +55,8 @@ enum
 	PROP_MINIMUM_WORD_SIZE,
 	PROP_INTERACTIVE_DELAY,
 	PROP_PRIORITY,
-	PROP_ACTIVATION
+	PROP_ACTIVATION,
+	N_PROPERTIES
 };
 
 struct _GtkSourceCompletionWordsPrivate
@@ -92,6 +91,8 @@ typedef struct
 	GtkSourceCompletionWordsBuffer *buffer;
 } BufferBinding;
 
+static GParamSpec *properties[N_PROPERTIES];
+
 static void gtk_source_completion_words_iface_init (GtkSourceCompletionProviderIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkSourceCompletionWords,
@@ -236,7 +237,7 @@ gtk_source_completion_words_populate (GtkSourceCompletionProvider *provider,
 
 	if (word == NULL ||
 	    (activation == GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE &&
-	     g_utf8_strlen (word, -1) < words->priv->minimum_word_size))
+	     g_utf8_strlen (word, -1) < (glong)words->priv->minimum_word_size))
 	{
 		g_free (word);
 		gtk_source_completion_context_add_proposals (context, provider, NULL, TRUE);
@@ -423,76 +424,68 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+	object_class->get_property = gtk_source_completion_words_get_property;
+	object_class->set_property = gtk_source_completion_words_set_property;
 	object_class->dispose = gtk_source_completion_words_dispose;
 
-	object_class->set_property = gtk_source_completion_words_set_property;
-	object_class->get_property = gtk_source_completion_words_get_property;
+	properties[PROP_NAME] =
+		g_param_spec_string ("name",
+				     "Name",
+				     "The provider name",
+				     NULL,
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_NAME,
-	                                 g_param_spec_string ("name",
-	                                                      "Name",
-	                                                      "The provider name",
-	                                                      NULL,
-	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_ICON] =
+		g_param_spec_object ("icon",
+				     "Icon",
+				     "The provider icon",
+				     GDK_TYPE_PIXBUF,
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_ICON,
-	                                 g_param_spec_object ("icon",
-	                                                      "Icon",
-	                                                      "The provider icon",
-	                                                      GDK_TYPE_PIXBUF,
-	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_PROPOSALS_BATCH_SIZE] =
+		g_param_spec_uint ("proposals-batch-size",
+				   "Proposals Batch Size",
+				   "Number of proposals added in one batch",
+				   1,
+				   G_MAXUINT,
+				   300,
+				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_PROPOSALS_BATCH_SIZE,
-	                                 g_param_spec_uint ("proposals-batch-size",
-	                                                    "Proposals Batch Size",
-	                                                    "Number of proposals added in one batch",
-	                                                    1,
-	                                                    G_MAXUINT,
-	                                                    300,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_SCAN_BATCH_SIZE] =
+		g_param_spec_uint ("scan-batch-size",
+				   "Scan Batch Size",
+				   "Number of lines scanned in one batch",
+				   1,
+				   G_MAXUINT,
+				   50,
+				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_SCAN_BATCH_SIZE,
-	                                 g_param_spec_uint ("scan-batch-size",
-	                                                    "Scan Batch Size",
-	                                                    "Number of lines scanned in one batch",
-	                                                    1,
-	                                                    G_MAXUINT,
-	                                                    50,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_MINIMUM_WORD_SIZE] =
+		g_param_spec_uint ("minimum-word-size",
+				   "Minimum Word Size",
+				   "The minimum word size to complete",
+				   2,
+				   G_MAXUINT,
+				   2,
+				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_MINIMUM_WORD_SIZE,
-	                                 g_param_spec_uint ("minimum-word-size",
-	                                                    "Minimum Word Size",
-	                                                    "The minimum word size to complete",
-	                                                    2,
-	                                                    G_MAXUINT,
-	                                                    2,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_INTERACTIVE_DELAY] =
+		g_param_spec_int ("interactive-delay",
+				  "Interactive Delay",
+				  "The delay before initiating interactive completion",
+				  -1,
+				  G_MAXINT,
+				  50,
+				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_INTERACTIVE_DELAY,
-	                                 g_param_spec_int ("interactive-delay",
-	                                                   "Interactive Delay",
-	                                                   "The delay before initiating interactive completion",
-	                                                   -1,
-	                                                   G_MAXINT,
-	                                                   50,
-	                                                   G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-
-	g_object_class_install_property (object_class,
-	                                 PROP_PRIORITY,
-	                                 g_param_spec_int ("priority",
-	                                                   "Priority",
-	                                                   "Provider priority",
-	                                                   G_MININT,
-	                                                   G_MAXINT,
-	                                                   0,
-	                                                   G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_PRIORITY] =
+		g_param_spec_int ("priority",
+				  "Priority",
+				  "Provider priority",
+				  G_MININT,
+				  G_MAXINT,
+				  0,
+				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GtkSourceCompletionWords:activation:
@@ -501,15 +494,16 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	 *
 	 * Since: 3.10
 	 */
-	g_object_class_install_property (object_class,
-	                                 PROP_ACTIVATION,
-					 g_param_spec_flags ("activation",
-							     "Activation",
-							     "The type of activation",
-							     GTK_SOURCE_TYPE_COMPLETION_ACTIVATION,
-							     GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE |
-							     GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED,
-							     G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	properties[PROP_ACTIVATION] =
+		g_param_spec_flags ("activation",
+				    "Activation",
+				    "The type of activation",
+				    GTK_SOURCE_TYPE_COMPLETION_ACTIVATION,
+				    GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE |
+				    GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED,
+				    G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 }
 
 static gboolean
@@ -576,8 +570,8 @@ gtk_source_completion_words_init (GtkSourceCompletionWords *self)
 
 /**
  * gtk_source_completion_words_new:
- * @name: (allow-none): The name for the provider
- * @icon: (allow-none): A specific icon for the provider
+ * @name: (nullable): The name for the provider, or %NULL.
+ * @icon: (nullable): A specific icon for the provider, or %NULL.
  *
  * Returns: a new #GtkSourceCompletionWords provider
  */
