@@ -14,13 +14,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_SOURCE_COMPLETION_WORDS_BUFFER_H__
-#define __GTK_SOURCE_COMPLETION_WORDS_BUFFER_H__
+#ifndef GTK_SOURCE_COMPLETION_WORDS_BUFFER_H
+#define GTK_SOURCE_COMPLETION_WORDS_BUFFER_H
 
 #include <gtk/gtk.h>
 
@@ -69,9 +68,6 @@ G_GNUC_INTERNAL
 void		 gtk_source_completion_words_buffer_set_minimum_word_size	(GtkSourceCompletionWordsBuffer  *buffer,
 										 guint                            size);
 
-G_GNUC_INTERNAL
-GtkTextMark     *gtk_source_completion_words_buffer_get_mark			(GtkSourceCompletionWordsBuffer  *buffer);
-
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_COMPLETION_WORDS_BUFFER_H__ */
+#endif /* GTK_SOURCE_COMPLETION_WORDS_BUFFER_H */
