@@ -2,7 +2,7 @@
 /* gtksourcebuffer-private.h
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2013 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2013, 2016 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GTK_SOURCE_BUFFER_PRIVATE_H
@@ -29,7 +28,13 @@
 G_BEGIN_DECLS
 
 GTK_SOURCE_INTERNAL
-void			 _gtk_source_buffer_update_highlight		(GtkSourceBuffer        *buffer,
+void			 _gtk_source_buffer_update_syntax_highlight	(GtkSourceBuffer        *buffer,
+									 const GtkTextIter      *start,
+									 const GtkTextIter      *end,
+									 gboolean                synchronous);
+
+GTK_SOURCE_INTERNAL
+void			 _gtk_source_buffer_update_search_highlight	(GtkSourceBuffer        *buffer,
 									 const GtkTextIter      *start,
 									 const GtkTextIter      *end,
 									 gboolean                synchronous);
