@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -197,8 +196,11 @@ gtk_source_completion_context_get_property (GObject    *object,
 		case PROP_ITER:
 			{
 				GtkTextIter iter;
-				gtk_source_completion_context_get_iter (context, &iter);
-				g_value_set_boxed (value, &iter);
+
+				if (gtk_source_completion_context_get_iter (context, &iter))
+				{
+					g_value_set_boxed (value, &iter);
+				}
 			}
 			break;
 
