@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GTK_SOURCE_GUTTER_PRIVATE_H
@@ -28,11 +27,11 @@
 G_BEGIN_DECLS
 
 G_GNUC_INTERNAL
-GtkSourceGutter *	gtk_source_gutter_new		(GtkSourceView     *view,
+GtkSourceGutter *	_gtk_source_gutter_new		(GtkSourceView     *view,
 							 GtkTextWindowType  type);
 
 G_GNUC_INTERNAL
-void			gtk_source_gutter_draw		(GtkSourceGutter *gutter,
+void			_gtk_source_gutter_draw		(GtkSourceGutter *gutter,
 							 GtkSourceView   *view,
 							 cairo_t         *cr);
 
