@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1166,7 +1165,6 @@ gtk_source_map_init (GtkSourceMap *map)
 	g_object_set (map,
 	              "auto-indent", FALSE,
 	              "can-focus", FALSE,
-	              "draw-spaces", 0,
 	              "editable", FALSE,
 	              "expand", FALSE,
 	              "monospace", TRUE,
